@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profmanage.php,v 1.40 2010/10/11 20:27:48 gruberroland Exp $
+$Id: profmanage.php,v 1.42 2011/02/18 19:15:43 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2010  Roland Gruber
+  Copyright (C) 2003 - 2011  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -129,12 +129,16 @@ if (isset($_POST['submit'])) {
 	}
 	// rename profile
 	elseif ($_POST['action'] == "rename") {
-		if (preg_match("/^[a-z0-9_-]+$/i", $_POST['renfilename']) && !in_array($_POST['renfilename'], getConfigProfiles())) {
-			if (rename("../../config/" . $_POST['oldfilename'] . ".conf",
-				"../../config/" . $_POST['renfilename'] . ".conf")) {
+		if (preg_match("/^[a-z0-9_-]+$/i", $_POST['oldfilename']) && preg_match("/^[a-z0-9_-]+$/i", $_POST['renfilename']) && !in_array($_POST['renfilename'], getConfigProfiles())) {
+			if (rename("../../config/" . $_POST['oldfilename'] . ".conf", "../../config/" . $_POST['renfilename'] . ".conf")) {
 				$msg = _("Renamed profile.");
 			}
 			else $error = _("Could not rename file!");
+			// update default profile setting if needed
+			if ($cfg->default == $_POST['oldfilename']) {
+				$cfg->default = $_POST['renfilename'];
+				$cfg->save();
+			}
 		}
 		else $error = _("Profile name is invalid!");
 	}
@@ -191,7 +195,7 @@ if (!isset($cfg->default)) {
 		<form action="profmanage.php" method="post">
 		<table>
 		<tr><td>
-		<fieldset>
+		<fieldset class="ui-corner-all">
 			<legend><b> <?php echo _("Profile management"); ?> </b></legend>
 			<br>
 			<table cellspacing=0 border=0>
