@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: login.php,v 1.143 2011/02/18 19:15:43 gruberroland Exp $
+$Id: login.php,v 1.144 2011/05/21 10:58:22 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
@@ -464,7 +464,7 @@ if(!empty($_POST['checklogin'])) {
 				if ($searchResult) {
 					$searchInfo = @ldap_get_entries($searchLDAP->server(), $searchResult);
 					if ($searchInfo) {
-						$searchInfo = cleanLDAPResult($searchInfo);
+						cleanLDAPResult($searchInfo);
 						if (sizeof($searchInfo) == 0) {
 							$searchSuccess = false;
 							$searchError = _('Wrong password/user name combination. Please try again.');
