@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: ou_edit.php,v 1.36 2010/10/12 17:49:18 gruberroland Exp $
+$Id: ou_edit.php,v 1.38 2011/06/06 18:05:17 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -64,7 +64,8 @@ if (isset($_POST['createOU']) || isset($_POST['deleteOU'])) {
 		if (preg_match("/^[a-z0-9 _\\-]+$/i", $_POST['newOU'])) {
 			// check if ou already exists
 			$new_dn = "ou=" . $_POST['newOU'] . "," . $_POST['parentOU'];
-			if (!in_array($new_dn, $_SESSION['ldap']->search_units($_POST['parentOU']))) {
+			$found = ldapGetDN($new_dn);
+			if ($found == null) {
 				// add new ou
 				$ou = array();
 				$ou['objectClass'] = "organizationalunit";
@@ -167,14 +168,14 @@ function display_main($message, $error) {
 	$options = array();
 	foreach ($types as $name => $title) {
 		$elements = array();
-		$units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_Suffix($name));
+		$units = searchLDAPByAttribute(null, null, 'organizationalunit', array('dn'), array($name));
 		for ($u = 0; $u < sizeof($units); $u++) {
-			$elements[getAbstractDN($units[$u])] = $units[$u];
+			$elements[getAbstractDN($units[$u]['dn'])] = $units[$u]['dn'];
 		}
 		$options[$title] = $elements;
 	}
 	// new OU
-	$container->addElement(new htmlOutputText(_("New organizational unit")));
+	$container->addElement(new htmlOutputText(_("New organisational unit")));
 	$parentOUSelect = new htmlSelect('parentOU', $options, array());
 	$parentOUSelect->setContainsOptgroups(true);
 	$parentOUSelect->setHasDescriptiveElements(true);
@@ -188,7 +189,7 @@ function display_main($message, $error) {
 	$container->addElement(new htmlSpacer(null, '10px'), true);
 
 	// delete OU
-	$container->addElement(new htmlOutputText(_("Delete organizational unit")));
+	$container->addElement(new htmlOutputText(_("Delete organisational unit")));
 	$deleteableOUSelect = new htmlSelect('deleteableOU', $options, array());
 	$deleteableOUSelect->setContainsOptgroups(true);
 	$deleteableOUSelect->setHasDescriptiveElements(true);
